California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 016 - ACA 5 (RESOLUTION CHAPTER 23), WEBER. GOVERNMENT PREFERENCES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1425738 | YES ON 16, OPPORTUNITY FOR ALL COALITION, SPONSORED BY CIVIL RIGHTS ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427809 | CALIFORNIANS FOR EQUAL RIGHTS, NO ON 16 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1365621 | ORANGE CLUB, PRIMARILY FORMED TO OPPOSE PROP 16 2020; THE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428832 | YES ON PROP. 16, CALIFORNIA BUSINESSES AND WORKING FAMILIES FOR FAIR OPPORTUNITIES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428004 | PADILLA BALLOT MEASURE COMMITTEE FOR DEMOCRACY AND JUSTICE - YES ON PROPOSITIONS 16, 17, AND 18; ALEX | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427838 | VOTERS FOR AFFIRMATIVE ACTION COMMITTEE IN SUPPORT OF ACA 5 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428061 | PARENTS AND STUDENTS FOR RACIAL EQUALITY, NO ON PROP 16 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1432304 | EDUCATORS FOR EQUITY, YES ON 15 AND 16, SPONSORED BY CALIFORNIA TEACHERS ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431801 | ALTAMED HEALTH SERVICES CORPORATION (NONPROFIT 501(C)(3)) YES ON 15, 16, AND 17 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431854 | RODRIGUEZ BALLOT MEASURE COMMITTEE; COMMITTEE FOR AN EQUITABLE LOS ANGELES, YES ON 16 & 19, COUNCILWOMAN MONICA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385557 | GONZALEZ BALLOT MEASURE COMMITTEE - YES ON PROP. 16; OUR VOICE OUR VOTE - ASM. LORENA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1395636 | SPEAK UP - YES ON 15 AND 16/ SUPPORTING KOZIATEK AND ORTIZ-FRANKLIN FOR SCHOOL BOARD 2020 (NONPROFIT 501(C(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431296 | NATIONAL ASSOCIATION OF INVESTMENT COMPANIES "NON-PROFIT 501(C)(6)" - YES ON PROPOSITION 16 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1426469 | EXCELLENCE IN EDUCATION, NO ON PROP 16 | OPPOSE